@@ -19,7 +19,9 @@ module Test.MockCat.WithMock
   ( withMock
   , withMockIO
   , askWithMockContext
-  , expects
+  , HasMockContext(..)
+  , addRecorderLocal
+  ,expects
   , MockResult(..)
   , called
   , with
@@ -40,15 +42,17 @@ module Test.MockCat.WithMock
   ) where
 
 import Control.Monad.IO.Class (MonadIO, liftIO)
-import Control.Monad.Reader (ReaderT(..), runReaderT)
+import Control.Monad.Reader (ReaderT(..), runReaderT, ask)
 import Control.Exception (bracket_)
 import Control.Concurrent.STM (newTVarIO, readTVarIO, atomically, modifyTVar')
 import Control.Monad.State (get, put, modify)
+import Data.Dynamic (Dynamic)
 import Test.MockCat.Verify (TimesSpec(..), times, once, never, atLeast, atMost, greaterThan, lessThan, anything, ResolvableMock, ResolvableParamsOf)
 import Test.MockCat.Internal.Verify (verifyExpectationDirect)
 import Test.MockCat.Internal.Types
   ( VerifyOrderMethod(..)
   , WithMockContext(..)
+  , MockName
   , Expectation(..)
   , Expectations(..)
   , runExpectations
@@ -72,22 +76,25 @@ newtype MockResult params = MockResult ()
 
 
 -- | Run a block with mock expectations that are automatically verified
+--   This implementation does NOT use threadWithMockStore (no unsafePerformIO)
+--   because the context is passed via ReaderT environment.
 withMock :: ReaderT WithMockContext IO a -> IO a
 withMock action = do
   ctxVar <- newTVarIO []
-  let ctx = WithMockContext ctxVar
-  bracket_ (setThreadWithMockContext ctx) clearThreadWithMockContext $ do
-    result <- runReaderT action ctx
-    -- Verify all registered verification actions
-    actions <- readTVarIO ctxVar
-    sequence_ actions
-    pure result
+  recordersVar <- newTVarIO []
+  let ctx = WithMockContext ctxVar recordersVar
+  result <- runReaderT action ctx
+  -- Verify all registered verification actions
+  actions <- readTVarIO ctxVar
+  sequence_ actions
+  pure result
 
 -- | IO version of withMock
 withMockIO :: IO a -> IO a
 withMockIO action = do
   ctxVar <- newTVarIO []
-  let ctx = WithMockContext ctxVar
+  recordersVar <- newTVarIO []
+  let ctx = WithMockContext ctxVar recordersVar
   bracket_ (setThreadWithMockContext ctx) clearThreadWithMockContext $ do
     result <- action
     -- Verify all registered verification actions
@@ -97,6 +104,33 @@ withMockIO action = do
 
 -- | Retrieve the current mock context from thread-local storage.
 --   Throws an error if no context is found.
+-- | Capability to access mock context
+--   This type class separates safe (ReaderT-based) context access
+--   from unsafe (global registry-based) context access.
+--
+--   Instances:
+--   - 'ReaderT WithMockContext m': Safe, uses 'ask' (no unsafePerformIO)
+--   - 'IO': Unsafe, uses global registry (unsafePerformIO dependency)
+class Monad m => HasMockContext m where
+  getMockContext :: m WithMockContext
+
+-- | Safe instance: ReaderT-based context access
+--   Uses 'ask' to obtain context from the ReaderT environment.
+--   This does NOT use unsafePerformIO.
+instance MonadIO m => HasMockContext (ReaderT WithMockContext m) where
+  getMockContext = ask
+
+-- | Unsafe instance: IO-based context access
+--   Uses global registry (threadWithMockStore) which is initialized
+--   with unsafePerformIO. This is kept for backward compatibility
+--   with 'withMockIO'.
+instance HasMockContext IO where
+  getMockContext = askWithMockContext
+
+-- | Get WithMockContext from thread-local storage
+--   This is used by the IO instance of HasMockContext.
+--   It relies on the global registry (threadWithMockStore) which
+--   is initialized with unsafePerformIO.
 askWithMockContext :: IO WithMockContext
 askWithMockContext = do
   mCtx <- getThreadWithMockContext
@@ -104,6 +138,15 @@ askWithMockContext = do
     Just ctx -> pure ctx
     Nothing -> errorWithoutStackTrace "askWithMockContext: No WithMockContext found in current thread. Use withMock or withMockIO."
 
+-- | Add a recorder to the local context (ReaderT environment)
+--   This does NOT use unsafePerformIO or global registry.
+--   Used by RegisterMock instance for safe registration.
+addRecorderLocal :: (HasMockContext m, MonadIO m)
+  => Maybe MockName -> Dynamic -> m ()
+addRecorderLocal name dyn = do
+  WithMockContext {contextRecorders = ref} <- getMockContext
+  liftIO $ atomically $ modifyTVar' ref ((name, dyn):)
+
 -- | Attach expectations to a mock function
 --   Supports both single expectation and multiple expectations in a do block
 infixl 0 `expects`
@@ -168,9 +211,12 @@ class ExpectsDispatchImpl (flag :: Bool) fn exp m where
   expectsDispatchImpl :: m fn -> exp -> m fn
 
 -- | Instance for normal mocks (flag ~ 'False)
---   Strict matching of params
+--   Uses HasMockContext to obtain context, which automatically selects:
+--   - ReaderT: ask (safe, no unsafePerformIO)
+--   - IO: askWithMockContext (unsafe, uses global registry)
 instance
-  ( MonadIO m
+  ( HasMockContext m
+  , MonadIO m
   , ResolvableMock fn
   , ResolvableParamsOf fn ~ params
   , ExtractParams exp
@@ -182,7 +228,7 @@ instance
   ExpectsDispatchImpl 'False fn exp m
   where
   expectsDispatchImpl mockFnM exp = do
-    WithMockContext ctxVar <- liftIO askWithMockContext
+    WithMockContext {contextVerifications = ctxVar} <- getMockContext  -- Updated pattern
     -- Try to help type inference by using exp first
     let _ = extractParams exp :: Proxy params
     mockFn <- mockFnM
@@ -201,8 +247,10 @@ instance
 
 -- | Instance for MockResult mocks (flag ~ 'True)
 --   Dynamic resolution using expectation params
+--   Uses HasMockContext for capability-based context access
 instance
-  ( MonadIO m
+  ( HasMockContext m
+  , MonadIO m
   , BuildExpectations (MockResult params) (Expectations params ()) params
   , Show params
   , EqParams params
@@ -210,7 +258,7 @@ instance
   ExpectsDispatchImpl 'True (MockResult params) (Expectations params ()) m
   where
   expectsDispatchImpl mockFnM exp = do
-    WithMockContext ctxVar <- liftIO askWithMockContext
+    WithMockContext {contextVerifications = ctxVar} <- getMockContext  -- Updated pattern
     _ <- mockFnM
     (mockName, mRecorder) <- liftIO MockRegistry.getLastRecorderRaw
     resolved <- case mRecorder of
@@ -226,8 +274,10 @@ instance
 
 -- | Instance for Unit mocks (flag ~ 'True)
 --   Dynamic resolution using expectation params
+--   Uses HasMockContext for capability-based context access
 instance
-  ( MonadIO m
+  ( HasMockContext m
+  , MonadIO m
   , BuildExpectations () (Expectations params ()) params
   , Show params
   , EqParams params
@@ -235,7 +285,7 @@ instance
   ExpectsDispatchImpl 'True () (Expectations params ()) m
   where
   expectsDispatchImpl mockFnM exp = do
-    WithMockContext ctxVar <- liftIO askWithMockContext
+    WithMockContext {contextVerifications = ctxVar} <- getMockContext  -- Updated pattern
     _ <- mockFnM
     (mockName, mRecorder) <- liftIO MockRegistry.getLastRecorderRaw
     resolved <- case mRecorder of
