@@ -3,7 +3,6 @@
 {-# LANGUAGE DataKinds #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE FlexibleContexts #-}
-{-# LANGUAGE MultiParamTypeClasses #-}
 {-# LANGUAGE UndecidableInstances #-}
 {-# LANGUAGE AllowAmbiguousTypes #-}
 {-# LANGUAGE FunctionalDependencies #-}
@@ -63,6 +62,7 @@ stripQualifiers =
       , "Internal."
       , "Test.MockCat.Mock."
       , "Test.MockCat.Types."
+      , "Test.MockCat.WithMock."
       ])
   where
     stripPrefixes [] t = t
@@ -374,7 +374,7 @@ spec = describe "TH generated vs handwritten instances" do
     it "_findIds signature matches handwritten" $
       assertHelperSigMatches partialMockSpecPath generatedFinderSigMap "_findIds"
 
-    it "_toUserInput signature omits redundant ResolvableParamsOf constraint" do
+    it "_toUserInput signature contains ResolvableParamsOf (due to MockResult wrapper)" do
       let genSig =
             Map.lookup "_toUserInput" generatedUserInputSigMap
       case genSig of
@@ -382,7 +382,7 @@ spec = describe "TH generated vs handwritten instances" do
           expectationFailure "TH generated signature not found: _toUserInput"
         Just sig ->
           normalizeSignature sig
-            `shouldNotSatisfy` T.isInfixOf (T.pack "ResolvableParamsOf") . T.pack
+            `shouldSatisfy` T.isInfixOf (T.pack "ResolvableParamsOf") . T.pack
 
     it "_produce signature matches handwritten" $
       assertHelperSigMatches typeClassSpecPath generatedAssocSigMap "_produce"
