@@ -8,7 +8,6 @@
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE TypeOperators #-}
-{-# OPTIONS_GHC -fno-cse -fno-full-laziness #-}
 {-# OPTIONS_GHC -Wno-unused-do-bind #-}
 {-# OPTIONS_GHC -Wno-orphans #-}
 
@@ -22,7 +21,7 @@ import Test.MockCat.SharedSpecDefs
 import GHC.IO (evaluate)
 import Control.Concurrent.Async (async, wait)
 import Control.Concurrent (threadDelay)
-import Control.Monad (void, forM, forM_)
+import Control.Monad (void, forM, forM_, replicateM)
 import Control.Monad.IO.Unlift (withRunInIO)
 import Control.Monad.IO.Class (liftIO)
 import Control.Exception (try, ErrorCall(..))
@@ -67,23 +66,23 @@ spec = do
 
   describe "withMock basic functionality" $ do
     it "simple mock with expects" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True) `expects` (called once `with` "a")
         liftIO $ mockFn "a" `shouldBe` True
 
     it "simple mock with expects using param" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True) `expects` (called once `with` param "a")
         liftIO $ mockFn "a" `shouldBe` True
 
     it "fails when not called" $ do
-      withMock (do 
+      withMock (do
         mock (any @String ~> True)
           `expects` (called once `with` "a")
         pure ()) `shouldThrow` anyErrorCall
 
     it "error message when not called" $ do
-      result <- try $ withMock $ do 
+      result <- try $ withMock $ do
         mock (any @String ~> True)
           `expects` (called once `with` "a")
         pure ()
@@ -97,7 +96,7 @@ spec = do
         _ -> fail "Expected ErrorCall"
 
     it "atLeast expectation" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True) `expects` (called (atLeast 1) `with` "a")
 
         void $ liftIO $ evaluate $ mockFn "a"
@@ -105,14 +104,14 @@ spec = do
         void $ liftIO $ evaluate $ mockFn "a"
 
     it "anything expectation" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` called once
 
         void $ liftIO $ evaluate $ mockFn "a"
 
     it "anything expectation error message when not called" $ do
-      result <- try $ withMock $ do 
+      result <- try $ withMock $ do
         mock (any @String ~> True)
           `expects` called once
         pure ()
@@ -130,34 +129,34 @@ spec = do
 
 
     it "never expectation without args succeeds when not called" $ do
-      withMock $ do 
+      withMock $ do
         mock (any @String ~> True)
           `expects` called never
         pure ()
 
     it "never expectation without args fails when called" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` called never
         liftIO $ mockFn "a" `shouldBe` True
         pure ()) `shouldThrow` anyErrorCall
 
     it "never expectation with args succeeds when not called with that arg" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` (called never `with` "z")
         liftIO $ mockFn "a" `shouldBe` True
         pure ()
 
     it "never expectation with args fails when called with that arg" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` (called never `with` "z")
         liftIO $ mockFn "z" `shouldBe` True
         pure ()) `shouldThrow` anyErrorCall
 
     it "multiple expectations in do block" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 2) `with` "a"
@@ -168,7 +167,7 @@ spec = do
         pure ()
 
     it "multiple expectations in do block fails when not all satisfied" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 2) `with` "a"
@@ -179,7 +178,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "multiple expectations in do block with never" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called once `with` "a"
@@ -188,7 +187,7 @@ spec = do
         pure ()
 
     it "multiple expectations in do block with never fails when violated" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called once `with` "a"
@@ -198,7 +197,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "multiple expectations with different counts" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 3) `with` "a"
@@ -213,7 +212,7 @@ spec = do
         pure ()
 
     it "multiple expectations fails when count is insufficient" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 3) `with` "a"
@@ -225,7 +224,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "multiple expectations fails when atLeast is not satisfied" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (atLeast 2) `with` "a"
@@ -236,7 +235,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "multiple expectations with mixed never and count" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 2) `with` "a"
@@ -248,7 +247,7 @@ spec = do
         pure ()
 
     it "multiple expectations with never fails when never is violated" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 2) `with` "a"
@@ -262,7 +261,7 @@ spec = do
 
   describe "withMock verification failures" $ do
     it "fails when called fewer times than expected" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called (times 3) `with` "a"
@@ -272,7 +271,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "fails when called with unexpected arguments" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called once `with` "a"
@@ -281,7 +280,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "fails when called but never expected" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             called never `with` "z"
@@ -301,7 +300,7 @@ spec = do
 
   describe "order verification" $ do
     it "calledInOrder succeeds when called in correct order" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInOrder ["a", "b", "c"]
@@ -312,7 +311,7 @@ spec = do
         pure ()
 
     it "calledInOrder fails when called in wrong order" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInOrder ["a", "b", "c"]
@@ -323,7 +322,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "calledInOrder fails when not all calls are made" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInOrder ["a", "b", "c"]
@@ -334,7 +333,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "calledInSequence succeeds when sequence is followed" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInSequence ["a", "c"]
@@ -345,7 +344,7 @@ spec = do
         pure ()
 
     it "calledInSequence fails when sequence is violated" $ do
-      withMock (do 
+      withMock (do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInSequence ["a", "c"]
@@ -355,7 +354,7 @@ spec = do
         pure ()) `shouldThrow` anyErrorCall
 
     it "calledInSequence succeeds with extra calls in between" $ do
-      withMock $ do 
+      withMock $ do
         mockFn <- mock (any @String ~> True)
         pure mockFn `expects` do
             calledInSequence ["a", "c"]
@@ -368,10 +367,10 @@ spec = do
 
   describe "multiple mocks" $ do
     it "can define multiple mocks in withMock" $ do
-      withMock $ do 
+      withMock $ do
         fn1 <- mock (any @String ~> True)
         pure fn1 `expects` do
-            called once `with` "a" 
+            called once `with` "a"
 
         fn2 <- mock (any @String ~> any @String ~> False)
         pure fn2 `expects` do
@@ -384,14 +383,14 @@ spec = do
   describe "withMock scope isolation" $ do
     it "mocks from different withMock blocks do not interfere" $ do
       -- First withMock block: expect one call
-      withMock $ do 
+      withMock $ do
         fn1 <- mock (any @String ~> True)
         pure fn1 `expects` do
             called once `with` "a"
         liftIO $ evaluate $ fn1 "a"
 
       -- Second withMock block: expect zero (if leaked, would see 1 and fail)
-      withMock $ do 
+      withMock $ do
         mock (any @String ~> True)
           `expects` do
             called never `with` "a"
@@ -453,17 +452,14 @@ spec = do
           total = threads * callsPerThread :: Int
 
       withMock $ do
-        mockFn <- mock (any ~> True)
-        pure mockFn `expects` do
-            called (times total)
+        mockFn <- mockM (any @String ~> True)
+          `expects` called (times total)
 
         withRunInIO $ \runInIO -> do
-          as <- forM [1 .. threads] $ \threadIx ->
-            async $ runInIO $ do
-              forM_ [1 .. callsPerThread] $ \callIx -> do
-                let tag = threadIx * 1000 + callIx
-                liftIO $ evaluate $ perCall tag (mockFn "stress")
-                liftIO $ threadDelay 1
+          as <- replicateM threads (async $ runInIO $ do
+              forM_ [1 .. callsPerThread] $ \_ -> do
+                void $ mockFn "stress"
+                liftIO $ threadDelay 1)
           mapM_ wait as
 
     it "concurrent calls preserve order expectations" $ do
